@@ -1,4 +1,5 @@
 import tkinter as tk
+import tkinter.messagebox as tkm
 from os import mkdir
 import json
 from . import GuiStyle
@@ -20,17 +21,6 @@ class Designer:
         :param kwargs: available kwargs:
             master, width, height, title, show, share_locals, share_globals
         """
-        self.identifiers2 = {"color": "background",
-                        "bordercolor": "highlightbackground",
-                        "bordercolorwidth": "highlightthickness",
-                        "activecolor": "activebackground",
-                        "textcolor": "foreground",
-                        "activetextcolor": "activeforeground",
-                        "disabledtextcolor": "disabledforeground",
-                        "activebordercolor": "highlightcolor"}
-        self.identifiers = [i for i in self.identifiers2]
-        for a in self.identifiers2.values():
-            self.identifiers.append(a)
         self.selected = ""
         self.changed_widgets = {}
         self.rgb_value = None
@@ -38,9 +28,8 @@ class Designer:
         self.name = "default"
         self.var_name_data = None
         self.Thread1 = None
-        self.kwargs = kwargs
         self.args = args
-        self._color_data = ["activebackground",
+        self.__color_data = ["activebackground",
                             "activeforeground",
                             "background",
                             "disabledforeground",
@@ -48,22 +37,14 @@ class Designer:
                             "highlightbackground",
                             "highlightcolor"]
 
-        self._all_available_kwargs = ["master", "width", "height", "title", "show", "share_locals", "share_globals"]
-        self._kwargs_fix = {"master": lambda: tk.Tk(),
-                            "width": 400,
-                            "height": 500,
-                            "title": "Tkinter expansion designer",
-                            "show": True,
-                            "share_locals": None,
-                            "share_globals": None}
+        self._all_available_kwargs = ["master", "width", "height", "title", "show"]
+        self.kwargs = {"master": lambda: tk.Tk(),
+                       "width": 400,
+                       "height": 500,
+                       "title": "Tkinter expansion designer",
+                       "show": True}
 
-        for i in self._all_available_kwargs:
-            try:
-                self.kwargs[i]
-            except KeyError:
-                self.kwargs[i] = self._kwargs_fix[i]
-        self.share_locals = self.kwargs["share_locals"]
-        self.share_globals = self.kwargs["share_globals"]
+        self.kwargs.update(kwargs)
         self.window = tk.Toplevel(self.kwargs["master"])
         self.window.resizable(False, False)
         self.window.title(self.kwargs["title"])
@@ -91,15 +72,15 @@ class Designer:
         self.ColorBlueInput.insert(0, "0")
 
         self.ColorRedInput.bind("<KeyRelease>", lambda _: self.Color.configure(
-            background=self._get_rgb(self.ColorRedInput,
+            background=self.__get_rgb(self.ColorRedInput,
                                      self.ColorGreenInput,
                                      self.ColorBlueInput)))
         self.ColorGreenInput.bind("<KeyRelease>", lambda _: self.Color.configure(
-            background=self._get_rgb(self.ColorRedInput,
+            background=self.__get_rgb(self.ColorRedInput,
                                      self.ColorGreenInput,
                                      self.ColorBlueInput)))
         self.ColorBlueInput.bind("<KeyRelease>", lambda _: self.Color.configure(
-            background=self._get_rgb(self.ColorRedInput,
+            background=self.__get_rgb(self.ColorRedInput,
                                      self.ColorGreenInput,
                                      self.ColorBlueInput)))
 
@@ -117,14 +98,14 @@ class Designer:
         else:
             self.window.destroy()
 
-        self.show = kwargs["show"]
+        self.show = self.kwargs["show"]
 
-    def set_rgb(self, what_to_change: tk.Event):
-        what_to_change.widget.configure(background=self._get_rgb(self.ColorRedInput,
+    def __set_rgb(self, what_to_change: tk.Event):
+        what_to_change.widget.configure(background=self.__get_rgb(self.ColorRedInput,
                                                                  self.ColorGreenInput,
                                                                  self.ColorBlueInput))
 
-    def _get_rgb(self, *args: tk.Entry):
+    def __get_rgb(self, *args: tk.Entry):
         final_values = []
         for i in args:
             self._term_i = i.get()
@@ -134,27 +115,30 @@ class Designer:
                 final_values.append(0)
         return rgb_to_hex(final_values[0], final_values[1], final_values[2])
 
-    def select_widget(self, part: tk.Event):
-        if self.un_select():
+    def __select_widget(self, part: tk.Event):
+        if self.__un_select():
             return
-        yy = 0.29
-        for i in self._color_data:
-            self.tmp_Button = tk.Button(self.window, text=f"Change {i}", command=lambda y=i:
-            self._color_parts(part, y))
-            self.tmp_Button.place(x=14, rely=yy)
-            yy += 0.06
-        self.Name.configure(text=f"Name: {id(part.widget)}")
-        self.var_data = _get_var_by_id(id(part.widget), self.share_globals)
-        self.var_name_data = _get_var_by_name(self.var_data[0], self.share_locals)[0]
+        yy = 0.30
+        for i in self.__color_data:
+            tmp_button = tk.Button(self.window, text=f"Change {i}", command=lambda y=i:
+            self.__color_parts(part, y))
+            tmp_button.place(x=14, rely=yy)
+            yy += 0.062
+        self.Name.configure(text=f"Name: {str(part.widget).split('.')[-1]}")
+        self.var_data = str(part.widget).split(".")[-1]
+        self.var_name_data = str(part.widget).split(".")[-1]
+        finder = 0
+        for i in list(self.changed_widgets.items()):
+            finder += i.count(self.var_name_data)
         try:
-            if list(self.changed_widgets.items())[0].count(self.var_name_data) > 0:
+            if finder > 0:
                 pass
             else:
                 self.changed_widgets[self.var_name_data] = {}
         except IndexError:
             self.changed_widgets[self.var_name_data] = {}
 
-    def _color_parts(self, part: tk.Event, value: str):
+    def __color_parts(self, part: tk.Event, value: str):
         self.selected = value
         try:
             self.rgb_value = hex_to_rgb(part.widget.cget(value).replace("#", ""))
@@ -167,16 +151,18 @@ class Designer:
         self.ColorBlueInput.delete(0, tk.END)
         self.ColorBlueInput.insert(0, self.rgb_value[2])
         self.Color.configure(background=part.widget.cget(value))
-        self.ApplyButton.configure(command=lambda: self._apply_values(part))
-        self.SaveButton.configure(command=lambda: self.save(self.name))
+        self.ApplyButton.configure(command=lambda: self.__apply_values(part))
+        self.SaveButton.configure(command=lambda: self.__save(self.name))
 
-    def _apply_values(self, part: tk.Event):
-        self.apply_text = f"'{self._get_rgb(self.ColorRedInput, self.ColorGreenInput, self.ColorBlueInput)}'"
-        exec("part.widget.configure(" + f"{self.selected}=" + self.apply_text + ")")
-        self.changed_widgets[self.var_name_data][self.selected] = str(part.widget.cget(self.selected))
-        print(self.changed_widgets)
+    def __apply_values(self, part: tk.Event):
+        self.apply_text = f"'{self.__get_rgb(self.ColorRedInput, self.ColorGreenInput, self.ColorBlueInput)}'"
+        try:
+            part.widget.configure({self.selected: self.apply_text.replace("'", "")})
+            self.changed_widgets[self.var_name_data][self.selected] = str(part.widget.cget(self.selected))
+        except tk.TclError:
+            tkm.showwarning("Designer", f"it looks like {self.selected} cannot be set for this widget")
 
-    def un_select(self):
+    def __un_select(self):
         try:
             self.Color.configure(background="black")
         except tk.TclError:
@@ -190,38 +176,82 @@ class Designer:
         self.ColorBlueInput.insert(0, "0")
         self.ApplyButton.configure(command=None)
 
-    def save(self, name="default"):
+    def __save(self, name="default"):
         try:
             mkdir("themes")
         except FileExistsError:
             pass
         with open(f"themes/{name}.json", "w") as file:
             json.dump(self.changed_widgets, file)
+        tkm.showinfo("Designer", "your theme was saved!")
 
-    def load(self):
+    def load(self, variables_to_change: dict):
+        """
+
+        load theme to widgets
+
+        :param variables_to_change: widgets you want to apply style to them
+        :return:
+        """
         give = False
         try:
             with open(f"themes/{self.name}.json") as file:
                 data = json.load(file)
-            for i in data:
-                for ii in data[i]:
-                    if ii not in self.identifiers:
-                        raise UnknownIdentifier(f"Identifier \"{ii}\" was not found! To get all"
-                                                          f" identifiers"
-                                                          f" use print(tkinter_expansion.identifiers())")
             for x, y in data.items():
                 self.changed_widgets[x] = {}
                 for a, b in y.items():
                     self.changed_widgets[x][a] = str(b)
-            return data
+                    self.changed_widgets[x][a] = str(b)
+            for value in variables_to_change:
+                if isinstance(variables_to_change[value], list):
+                    for index, val in enumerate(variables_to_change[value]):
+                        try:
+                            val.configure(data[value])
+                        except tk.TclError:
+                            pass
+                else:
+                    try:
+                        variables_to_change[value].configure(data[value])
+                    except tk.TclError:
+                        for i in data[value]:
+                            try:
+                                variables_to_change[value][i] = data[value][i]
+                            except tk.TclError:
+                                continue
         except FileNotFoundError:
             give = True
         if give:
             raise DesignerThemeNotFound(f"Theme with name {self.name} was not found in themes folder!")
 
     def set_theme_name(self, name="default"):
+        """
+
+        :param name: put name of theme you want to load
+        :return:
+        """
         self.name = name
 
+    def bind(self, widget):
+        """
+
+        :param widget: widget you want to bind to designer
+        :return:
+        """
+        if self.show:
+            widget.bind("<Button-3>", lambda event: self.__select_widget(event))
+            widget.bind_all("<Escape>", lambda event: self.__un_select())
+
+    def bind_all(self, widgets: list):
+        """
+
+        :param widgets: input widgets in list you want to bind to designer
+        :return:
+        """
+        for i in widgets:
+            if self.show:
+                i.bind("<Button-3>", lambda event: self.__select_widget(event))
+                i.bind_all("<Escape>", lambda event: self.__un_select())
+
 
 def rgb_to_hex(red: int, green: int, blue: int) -> str:
     """
@@ -254,23 +284,23 @@ def hex_to_rgb(hex_color: str) -> tuple:
     return tuple(int(hex_color[i:i + 2], 16) for i in (0, 2, 4))
 
 
-def _get_var_by_id(id_of_var, global_share):
-    return [x for x in list(global_share.values()) if id(x) == id_of_var]
+def bind_help(panel, text, timeout):
+    """
 
-
-def _get_var_by_name(var_data, shared_locals):
-    return [x for x, y in shared_locals.items() if y == var_data]
-
-
-def bind_help(panel, text):
-    panel.bind("<Enter>", lambda _: panel.after(500, _show_hint(panel, text=text)))
+    :param panel: widget you want to show hint on
+    :param text: help message
+    :param timeout: show after specific time in ms
+    :return:
+    """
+    panel.bind("<Enter>", lambda _: panel.after(timeout, __show_hint(panel, text=text)))
+    unbind_help(panel)
 
 
 def unbind_help(panel):
-    panel.bind("<Leave>", lambda _: _hide_hint())
+    panel.bind("<Leave>", lambda _: __hide_hint())
 
 
-def _show_hint(panel, text: str):
+def __show_hint(panel, text: str):
     global tmp_top, tmp_top_label
     x = y = 0
     x += panel.winfo_rootx() + 25
@@ -282,22 +312,8 @@ def _show_hint(panel, text: str):
     tmp_top_label.pack(ipadx=1)
 
 
-def identifiers():
-    identifiers2 = {"color": "background",
-                    "bordercolor": "highlightbackground",
-                    "bordercolorwidth": "highlightthickness",
-                    "activecolor": "activebackground",
-                    "textcolor": "foreground",
-                    "activetextcolor": "activeforeground",
-                    "disabledtextcolor": "disabledforeground",
-                    "activebordercolor": "highlightcolor"}
-    identifiers = [i for i in identifiers2]
-    for a in identifiers2.values():
-        identifiers.append(a)
-    return f"All supported identifiers: {', '.join(identifiers)}."
-
-
-def _hide_hint():
+def __hide_hint():
     global tmp_top_label, tmp_top
-    tmp_top_label.destroy()
-    tmp_top.destroy()
+    if tmp_top is not None and tmp_top_label is not None:
+        tmp_top_label.destroy()
+        tmp_top.destroy()
